==> ejc-quality-impl-3.0.0-20240307.073456-3-sources.jar: com/ejianc/business/educationtrain/bean/SpecialPersonRegisterDetailEntity.java <==
package com.ejianc.business.educationtrain.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 特种人员登记-子实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_quality_special_person_register_detail")
public class SpecialPersonRegisterDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="special_person_register_id")
    private Long specialPersonRegisterId; // 特种人员登记表主表id
    @TableField(value="name")
    private String name; // 姓名
    @TableField(value="sex")
    private String sex; // 性别
    @TableField(value="old")
    private Integer old; // 年龄
    @TableField(value="card_num")
    private String cardNum; // 证件号码
    @TableField(value="expiry_date")
    private String expiryDate; // 有效期至
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="construction_dept")
    private String constructionDept; // 施工单位
    
    
    

    public Long getSpecialPersonRegisterId() {
        return specialPersonRegisterId;
    }

    public void setSpecialPersonRegisterId(Long specialPersonRegisterId) {
        this.specialPersonRegisterId = specialPersonRegisterId;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getSex() {
        return sex;
    }

    public void setSex(String sex) {
        this.sex = sex;
    }
    public Integer getOld() {
        return old;
    }

    public void setOld(Integer old) {
        this.old = old;
    }
    public String getCardNum() {
        return cardNum;
    }

    public void setCardNum(String cardNum) {
        this.cardNum = cardNum;
    }
    public String getExpiryDate() {
        return expiryDate;
    }

    public void setExpiryDate(String expiryDate) {
        this.expiryDate = expiryDate;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getConstructionDept() {
        return constructionDept;
    }

    public void setConstructionDept(String constructionDept) {
        this.constructionDept = constructionDept;
    }
}

==> ejc-quality-impl-3.0.0-20240925.070511-95-sources.jar: com/ejianc/business/educationtrain/bean/SpecialPersonRegisterDetailEntity.java <==
package com.ejianc.business.educationtrain.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 特种人员登记-子实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_quality_special_person_register_detail")
public class SpecialPersonRegisterDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="special_person_register_id")
    private Long specialPersonRegisterId; // 特种人员登记表主表id
    @TableField(value="name")
    private String name; // 姓名
    @TableField(value="sex")
    private String sex; // 性别
    @TableField(value="old")
    private Integer old; // 年龄
    @TableField(value="card_num")
    private String cardNum; // 证件号码
    @TableField(value="expiry_date")
    private String expiryDate; // 有效期至
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="construction_dept")
    private String constructionDept; // 施工单位
    @TableField(value="work_type_id")
    private Long workTypeId; // 工种id
    @TableField(value="work_type_name")
    private String workTypeName; // 工种名称


    

    public Long getSpecialPersonRegisterId() {
        return specialPersonRegisterId;
    }

    public void setSpecialPersonRegisterId(Long specialPersonRegisterId) {
        this.specialPersonRegisterId = specialPersonRegisterId;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getSex() {
        return sex;
    }

    public void setSex(String sex) {
        this.sex = sex;
    }
    public Integer getOld() {
        return old;
    }

    public void setOld(Integer old) {
        this.old = old;
    }
    public String getCardNum() {
        return cardNum;
    }

    public void setCardNum(String cardNum) {
        this.cardNum = cardNum;
    }
    public String getExpiryDate() {
        return expiryDate;
    }

    public void setExpiryDate(String expiryDate) {
        this.expiryDate = expiryDate;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getConstructionDept() {
        return constructionDept;
    }

    public void setConstructionDept(String constructionDept) {
        this.constructionDept = constructionDept;
    }

    public Long getWorkTypeId() {
        return workTypeId;
    }

    public void setWorkTypeId(Long workTypeId) {
        this.workTypeId = workTypeId;
    }

    public String getWorkTypeName() {
        return workTypeName;
    }

    public void setWorkTypeName(String workTypeName) {
        this.workTypeName = workTypeName;
    }
}
